@@ -26,7 +26,7 @@ cocitation <- function(graph, v=V(graph)) {
     stop("Not a graph object")
   }
   on.exit( .Call("R_igraph_finalizer", PACKAGE="igraph") )
-  .Call("R_igraph_cocitation", graph, as.igraph.vs(v),
+  .Call("R_igraph_cocitation", graph, as.igraph.vs(graph, v),
         PACKAGE="igraph")
 }
 
@@ -35,6 +35,6 @@ bibcoupling <- function(graph, v=V(graph)) {
     stop("Not a graph object")
   }
   on.exit( .Call("R_igraph_finalizer", PACKAGE="igraph") )
-  .Call("R_igraph_bibcoupling", graph, as.igraph.vs(v),
+  .Call("R_igraph_bibcoupling", graph, as.igraph.vs(graph, v),
         PACKAGE="igraph")
 }
